@@ -1106,7 +1106,6 @@ def get_files(search_path=False, **kwargs):
             A list of dictionaries containing all matching files.
     '''
     file_array = []
-
     if search_path is False:
         search_path = obj.get_kwarg(['search path', 'search'], os.getcwd(), (str, list), **kwargs)
     if isinstance(search_path, list) is False:
@@ -1125,6 +1124,7 @@ def get_files(search_path=False, **kwargs):
             # The extension is required to gather the data.
             if "extension" not in data_include:
                 data_include.append("extension")
+    
 
     # ignore_array = obj.get_kwarg(['ignore', 'ignore_array', 'exclude'], [], (str, list), **kwargs)
     exclude = obj.get_kwarg(['exclude', 'ignore', 'ignore array'], [], (list, str), **kwargs)
@@ -1135,15 +1135,19 @@ def get_files(search_path=False, **kwargs):
     if isinstance(include, (str)):
         include = [include]
 
-    extension_array = strUtils.format.extension(obj.get_kwarg(['extensions', 'ext', 'extension'], [], (str, list), **kwargs))
+    # print(f"file.get_files.kwarg['extension']: ",obj.get_kwarg(['extensions', 'ext', 'extension'], [], (str, list), **kwargs))
+    extension_array = obj.get_kwarg(['extensions', 'ext', 'extension'], [], (str, list), **kwargs)
+    # print(f"extension_array - RAW: {extension_array}")
     extension_array = _gen_extension_array(extension_array)
-            
+    # print(f"extension_array: {extension_array}")
+    # print(f"file.get_files: {search_path}")
 
     ftp = obj.get_kwarg(["ftp"], None, None, **kwargs)
     if ftp is not None:
         return get_files_ftp(search_path, **kwargs)
 
     if threaded is True:
+        # print(f"file.get_files - Using threads for indexing.")
         for path in search_path:
             gft = GetFilesThreaded(path, recursive=recursive, data_include=data_include, exclude=exclude, include=include, extensions=extension_array,include_meta_data=include_meta_data)
             return gft.master()
@@ -1227,15 +1231,20 @@ def _add_jpg_meta_data(file_array):
     return file_array
 
 def _gen_extension_array(ext_array):
+    # print(f"_gen_extension_array.ext_array: {ext_array}")
     extension_array = []
     if isinstance(ext_array, (str)):
-        extension_array = [ext_array]
-    for ext in extension_array:
+        ext_array = [ext_array]
+        
+    for ext in ext_array:
         if ext == "images":
             extension_array = extension_array + PILLOW_SUPPORTED_IMAGE_EXTENSIONS
         else:
+            # print(f"_gen_extension_array.ext: {ext}")
             file_ext = strUtils.format.extension(ext)
             extension_array.append(file_ext)
+    if len(extension_array) > 1:
+        extension_array = list(set(extension_array))
     return extension_array
 
 def get_files_ftp(search_path=False, **kwargs):
@@ -1422,7 +1431,9 @@ class GetFilesThreaded:
         self.threads = new_threads
 
     def _get_data_thread(self, file_path):
+        # print(f"GetFilesThreaded._get_data_thread.file_path: {file_path}")
         file_data = get_data(file_path, data_include=self.data_include)
+        
         if file_data is not None:
             # ignore = False
             # print(f"file_data['extension']: {file_data['extension']}")
@@ -1484,6 +1495,7 @@ class GetFilesThreaded:
             `version`: 1.0
             `method_name`: master
         '''
+        # print(f"GetFilesThreaded.master")
         for path in self.search_path:
             # pylint: disable=unused-variable
             for root, folders, files in os.walk(path):
