@@ -548,28 +548,30 @@ def apply_keyword_synonyms(files,synonyms,**kwargs):
         kws_hash_prime = csu.gen.hash(kws)
         if isinstance(kws,(list)) is False:
             kws = [kws]
-        new_tags = kws
-        for key in kws:
-            # print(f"key: ",key)
-            if isinstance(key,(str)) is True:
-                if key in key_synonyms:
-                    for k in key_synonyms[key]:
-                        if k not in kws:
-                            new_tags.append(k)
-                        
+        # new_tags = kws
+        new_tags = apply_synonyms(kws,synonyms)
+        # for key in kws:
+            # # print(f"key: ",key)
+            # if isinstance(key,(str)) is True:
+            #     if key in key_synonyms:
+            #         for k in key_synonyms[key]:
+            #             if k not in new_tags:
+            #             # if k not in kws and k not in new_tags:
+            #                 new_tags.append(k)
         file['meta_data']['XMP:Subject'] = new_tags
         file['meta_data']['IPTC:Keywords'] = new_tags
+                        
         
-        print(f"kws_hash_prime: {kws_hash_prime}")
+        # print(f"kws_hash_prime: {kws_hash_prime}")
         # kws = cfu.file.image.get_keywords(file)
         kwsHash = csu.gen.hash(new_tags)
-        print(f"kwsHash:        {kwsHash}")
+        # print(f"kwsHash:        {kwsHash}")
         
         # compare the original keyword hash to the new one
         # if they are not identical, that means new keywords
         # were added, so we add it to the update_array.
         if kws_hash_prime != kwsHash:
-            print(f"new tags found.")
+            # print(f"new tags found.")
             # file['meta_data']['XMP:Subject'] = kws
             # file['meta_data']['IPTC:Keywords'] = kws
             update_array.append(file)
@@ -581,6 +583,33 @@ def apply_keyword_synonyms(files,synonyms,**kwargs):
         f.image.save_file_obj(update_array)
     return files_array
 
+def apply_synonyms(file_keys,synonyms):
+    if len(file_keys) > 1:
+        file_keys = list(set(file_keys))
+    file_keys_hash = csu.gen.hash(file_keys)
+    added_keys = False
+    new_file_keys = file_keys
+    for k,v in synonyms.items():
+        
+        if k in file_keys or k in new_file_keys:
+            new_keys = [x for x in v if x not in new_file_keys]
+            if len(new_keys) > 0:
+                added_keys = True
+                print(f"k: {k}:{v}")
+                new_file_keys.extend(new_keys)
+                print(f"new_file_keys: {new_file_keys}")
+                print(f"")
+        
+    if len(new_file_keys) > 1:
+        new_file_keys = list(set(new_file_keys))
+    
+    new_file_keys_hash = csu.gen.hash(new_file_keys)
+    # if new_file_keys_hash != file_keys_hash:
+    if added_keys is True:
+        return apply_synonyms(new_file_keys,synonyms)
+    else:
+        return new_file_keys
+
 def auto_tag_by_folder_name(watch_path,**kwargs):
     print(f"auto_tag_by_folder_name")
     synonyms = obj.get_kwarg(['synonyms'],False,(bool,dict),**kwargs)
@@ -650,7 +679,7 @@ def _tag_by_folder_name(files,exclude='',**kwargs):
         save_file_obj(update_array)
     return files_array
 
-def tag_if_missing_keyword(files,needles,keyword):
+def tag_if_missing_keyword(files,needles,keyword,**kwargs):
     update_array = []
     files_array = _parse_file_obj_list(files)
     print(f"")
@@ -666,6 +695,7 @@ def tag_if_missing_keyword(files,needles,keyword):
     result = has_keyword(files_array,needles,reverse=True)
     # add the "keyword" to them
     update_array.extend(add_keyword(result,keyword))
+    
     save_file_obj(update_array)
 
 
